@@ -1,6 +1,7 @@
 ;;; ebib-notes.el --- Part of Ebib, a BibTeX database manager  -*- lexical-binding: t -*-
 
-;; Copyright (c) 2003-2023 Joost Kremers
+;; Copyright (c) 2003-2024 Joost Kremers
+;; Copyright (c) 2022-2024 Hugo Heagren
 ;; All rights reserved.
 
 ;; Author: Joost Kremers <joostkremers@fastmail.fm>
@@ -146,6 +147,8 @@ Note that the `%K' specifier must be present in the template and
 should be replaced by an identifier that is unique for the entry.
 This identifier is used to retrieve the note.  Without it, Ebib
 is not able to determine whether an entry has a note or not.
+Note also that `%K` must occur on a line of its own, i.e., must
+be surrounded by \\n characters in the template.''
 
 The template can also contain the string \"%%?\" to indicate the
 position where the cursor is to be placed when creating a new
@@ -351,7 +354,7 @@ Otherwise just open the note file for KEY.
 Return a cons of the buffer and the position of the note in the
 buffer: in a multi-note file, this is the position of the
 Custom_ID of the note; if each note has its own file, the
-position is simply 1.
+position is set to point.
 
 If KEY has no note, return nil."
   (cond
@@ -373,7 +376,7 @@ If KEY has no note, return nil."
                  ;; Otherwise try and open the file.
                  (and (file-readable-p filename)
                       (ebib--notes-open-single-note-file filename)))))
-      (when buf (cons buf 1))))))
+      (when buf (cons buf (with-current-buffer buf (point))))))))
 
 (defun ebib--notes-create-new-note (key db)
   "Create a note for KEY in DB.
@@ -453,7 +456,7 @@ name is fully qualified by prepending the directory in
 Return the buffer but do not select it."
   (let ((buf (find-file-noselect file)))
     (with-current-buffer buf
-      (add-hook 'after-save-hook 'ebib--maybe-update-entry-buffer nil t))
+      (add-hook 'after-save-hook 'ebib--update-entry-buffer-keep-note))
     buf))
 
 ;;; Common notes file.
@@ -468,7 +471,7 @@ necessary.  If FILE cannot be opened, an error is raised."
         (error "[Ebib] Cannot read or create notes file"))
       (setq buf (find-file-noselect file))
       (with-current-buffer buf
-        (add-hook 'after-save-hook 'ebib--maybe-update-entry-buffer nil t)))
+        (add-hook 'after-save-hook 'ebib--update-entry-buffer-keep-note nil t)))
     buf))
 
 (provide 'ebib-notes)
